==> BestCrypt-2.0.7.tar.gz: BestCrypt-2.0.7/certificate/CertificateLib/symmetricAlgs/symmetricAlgs.h <==
/////////////////////////////////////////////////////////////////
//
//      Copyright (c) 1994-2012 Jetico, Inc., Finland
//      All rights reserved.
//
//      File: symmetricAlgs.h
//      Revision:
//      Created:
//      Description:
//
/////////////////////////////////////////////////////////////////

#ifndef __symmetricAlgs__
#define __symmetricAlgs__

#ifndef BYTE
typedef unsigned char BYTE;
#endif

#ifndef NULL
#define NULL 0
#endif

#include "../crtLibErrs.h"

//
//	12.12.2012
//	See Comments at cAlgBfish.cpp
//
extern bool crtLib_bWindowsDriverCompatible; // default = false;

typedef class cSymAlg * HSA; // Handle to symmetric algorithm


int sa_getIDsOfAvailableAlgAlgorithms( int *pIDsCount, int **ppIDsTab );
const char *sa_getSymmetricAlgName( BYTE algID );

int sa_createAlgorithm( HSA *pHSA, int algID, BYTE *keyBuff, int keyBuffSize );
void sa_free( HSA hSA );

int sa_getKeySize( int algID, int *pMax = NULL );
int sa_getBlockSize( HSA hSA );
int sa_getBlockSize( int algID );

bool sa_isValidID( int algID );

int sa_encrypt(
	HSA hSA,		// Handle of symmetric algorithm
	BYTE *outBf,		// Output encrypted buffer
	const BYTE *inBf,	// Input plaintext buffer. 
	int bfSize		// In/out buffers' size.
);

int sa_decrypt(
	HSA hSA,		// Handle of symmetric algorithm
	BYTE *outBf,		// Output plaintext buffer.
	const BYTE *inBf,	// Input encrypted buffer.
	int bfSize		// In/out buffers' size.
);

//
//	CBC mode operations
//		Note, buffer size has to be compatible with algorithm block size.
//
int sa_encryptCBC(
	HSA hSA,		// Handle of symmetric algorithm
	const BYTE *sync,     // Initial vector
	BYTE *outBf,	// Output encrypted buffer
	const BYTE *inBf,		// Input plaintext buffer. 
	int bfSize		// In/out buffers' size.
);

int sa_decryptCBC(
	HSA hSA,		// Handle of symmetric algorithm
	const BYTE *sync,     // Initial vector
	BYTE *outBf,	// Output plaintext buffer.
	const BYTE *inBf,		// Input encrypted buffer.
	int bfSize		// In/out buffers' size.
);

//
// Switch on BestCrypt driver CBC mode compatibility.
//
void sa_setBCDriverCompatible( HSA hSA, bool bSet = true );

//
//	CFB mode operations
//		Note, buffer size can be any integer.
//
int sa_initCFB( HSA hSA, const BYTE *iv );
int sa_syncCFB( HSA hSA );

int sa_encryptCFB( HSA hSA, BYTE *outBf, const BYTE *inBf, int bfSize );
int sa_decryptCFB( HSA hSA, BYTE *outBf, const BYTE *inBf, int bfSize );


#endif // __symmetricAlgs__

==> BestCrypt-2.0.14.tar.gz: BestCrypt-2.0.14/certificate/CertificateLib/symmetricAlgs/symmetricAlgs.h <==
/////////////////////////////////////////////////////////////////
//
//      Copyright (c) 1994-2012 Jetico, Inc., Finland
//      All rights reserved.
//
//      File: symmetricAlgs.h
//      Revision:
//      Created:
//      Description:
//
/////////////////////////////////////////////////////////////////

#ifndef __symmetricAlgs__
#define __symmetricAlgs__

#ifndef BYTE
typedef unsigned char BYTE;
#endif

#ifndef NULL
#define NULL 0
#endif

#include "../crtLibErrs.h"
#include "cSymAlg.h"

//
//	12.12.2012
//	See Comments at cAlgBfish.cpp
//
extern bool crtLib_bWindowsDriverCompatible; // default = false;

typedef class cSymAlg * HSA; // Handle to symmetric algorithm


int sa_getIDsOfAvailableAlgAlgorithms( int *pIDsCount, int **ppIDsTab );
const char *sa_getSymmetricAlgName( BYTE algID );

int sa_createAlgorithm( HSA *pHSA, int algID, BYTE *keyBuff, int keyBuffSize );
void sa_free( HSA hSA );

int sa_getKeySize( int algID, int *pMax = NULL );
int sa_getBlockSize( HSA hSA );
int sa_getBlockSize( int algID );

bool sa_isValidID( int algID );

int sa_encrypt(
	HSA hSA,		// Handle of symmetric algorithm
	BYTE *outBf,		// Output encrypted buffer
	const BYTE *inBf,	// Input plaintext buffer. 
	int bfSize		// In/out buffers' size.
);

int sa_decrypt(
	HSA hSA,		// Handle of symmetric algorithm
	BYTE *outBf,		// Output plaintext buffer.
	const BYTE *inBf,	// Input encrypted buffer.
	int bfSize		// In/out buffers' size.
);

//
//	CBC mode operations
//		Note, buffer size has to be compatible with algorithm block size.
//
int sa_encryptCBC(
	HSA hSA,		// Handle of symmetric algorithm
	const BYTE *sync,     // Initial vector
	BYTE *outBf,	// Output encrypted buffer
	const BYTE *inBf,		// Input plaintext buffer. 
	int bfSize		// In/out buffers' size.
);

int sa_decryptCBC(
	HSA hSA,		// Handle of symmetric algorithm
	const BYTE *sync,     // Initial vector
	BYTE *outBf,	// Output plaintext buffer.
	const BYTE *inBf,		// Input encrypted buffer.
	int bfSize		// In/out buffers' size.
);

//
// Switch on BestCrypt driver CBC mode compatibility.
//
void sa_setBCDriverCompatible( HSA hSA, cSymAlg::eCompatibleType eType );

//
//	CFB mode operations
//		Note, buffer size can be any integer.
//
int sa_initCFB( HSA hSA, const BYTE *iv );
int sa_syncCFB( HSA hSA );

int sa_encryptCFB( HSA hSA, BYTE *outBf, const BYTE *inBf, int bfSize );
int sa_decryptCFB( HSA hSA, BYTE *outBf, const BYTE *inBf, int bfSize );


#endif // __symmetricAlgs__
